pub struct ChatCompletionResponseMessageFunctionCall {
pub arguments: String,
pub name: String,
}Expand description
ChatCompletionResponseMessageFunctionCall : Deprecated and replaced by tool_calls. The name and arguments of a function that should be called, as generated by the model.
Fields
arguments: StringThe arguments to call the function with, as generated by the model in JSON format. Note that the model does not always generate valid JSON, and may hallucinate parameters not defined by your function schema. Validate the arguments in your code before calling your function.
name: StringThe name of the function to call.
Implementations
Sourceimpl ChatCompletionResponseMessageFunctionCall
impl ChatCompletionResponseMessageFunctionCall
Sourcepub fn builder() -> ChatCompletionResponseMessageFunctionCallBuilder
pub fn builder() -> ChatCompletionResponseMessageFunctionCallBuilder
Create an instance of ChatCompletionResponseMessageFunctionCall using the builder syntax
Sourceimpl ChatCompletionResponseMessageFunctionCall
impl ChatCompletionResponseMessageFunctionCall
Sourcepub fn new(
arguments: String,
name: String,
) -> ChatCompletionResponseMessageFunctionCall
pub fn new( arguments: String, name: String, ) -> ChatCompletionResponseMessageFunctionCall
Deprecated and replaced by tool_calls. The name and arguments of a function that should be called, as generated by the model.